@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: getinfo.c,v 1.27 2003/01/29 10:14:21 bagder Exp $
+ * $Id: getinfo.c,v 1.28 2003/05/01 13:37:36 bagder Exp $
  ***************************************************************************/
 
 #include "setup.h"
@@ -38,6 +38,8 @@
 /* Make this the last #include */
 #ifdef MALLOCDEBUG
 #include "memdebug.h"
+#else
+#include <stdlib.h>
 #endif
 
 /*
