@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: hostip.c,v 1.85 2003/03/19 09:16:59 bagder Exp $
+ * $Id: hostip.c,v 1.87 2003/05/13 12:12:17 bagder Exp $
  ***************************************************************************/
 
 #include "setup.h"
@@ -239,7 +239,7 @@ struct Curl_dns_entry *Curl_resolv(struct SessionHandle *data,
      will generate a signal and we will siglongjmp() from that here */
   if(!data->set.no_signal && sigsetjmp(curl_jmpenv, 1)) {
     /* this is coming from a siglongjmp() */
-    failf(data, "name lookup time-outed");
+    failf(data, "name lookup timed out");
     return NULL;
   }
 #endif
@@ -532,10 +532,6 @@ static char *MakeIP(unsigned long num, char *addr, int addr_len)
   return (addr);
 }
 
-#ifndef INADDR_NONE
-#define INADDR_NONE (in_addr_t) ~0
-#endif
-
 static void hostcache_fixoffset(struct hostent *h, int offset)
 {
   int i=0;
@@ -573,7 +569,8 @@ static Curl_addrinfo *my_getaddrinfo(struct SessionHandle *data,
   port=0; /* unused in IPv4 code */
   ret = 0; /* to prevent the compiler warning */
 
-  if ( (in=inet_addr(hostname)) != INADDR_NONE ) {
+  in=inet_addr(hostname);
+  if (in != CURL_INADDR_NONE) {
     struct in_addr *addrentry;
     struct namebuf {
         struct hostent hostentry;
