@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: http.c,v 1.124 2003/03/31 04:41:05 bagder Exp $
+ * $Id: http.c,v 1.128 2003/05/12 12:29:00 bagder Exp $
  ***************************************************************************/
 
 #include "setup.h"
@@ -491,16 +491,16 @@ CURLcode Curl_ConnectHTTPProxyTunnel(struct connectdata *conn,
             /* a newline is CRLF in ftp-talk, so the CR is ignored as
                the line isn't really terminated until the LF comes */
 
-            /* output debug output if that is requested */
-            if(data->set.verbose)
-              Curl_debug(data, CURLINFO_DATA_IN, line_start, perline);
-            
             if('\r' == line_start[0]) {
               /* end of headers */
               keepon=FALSE;
               break; /* breaks out of loop, not switch */
             }
 
+            /* output debug output if that is requested */
+            if(data->set.verbose)
+              Curl_debug(data, CURLINFO_HEADER_IN, line_start, perline);
+
             if(2 == sscanf(line_start, "HTTP/1.%d %d",
                            &subversion,
                            &httperror)) {
@@ -626,6 +626,7 @@ CURLcode Curl_http(struct connectdata *conn)
   char *ppath = conn->ppath; /* three previous function arguments */
   char *host = conn->name;
   const char *te = ""; /* tranfer-encoding */
+  char *ptr;
 
   if(!conn->proto.http) {
     /* Only allocate this struct if we don't already have it! */
@@ -714,30 +715,30 @@ CURLcode Curl_http(struct connectdata *conn)
     }
   }
 
-  if(data->cookies) {
-    co = Curl_cookie_getlist(data->cookies,
-                             host, ppath,
-                             (bool)(conn->protocol&PROT_HTTPS?TRUE:FALSE));
-  }
-  if (data->change.proxy && *data->change.proxy &&
-      !data->set.tunnel_thru_httpproxy &&
-      !(conn->protocol&PROT_HTTPS))  {
-    /* The path sent to the proxy is in fact the entire URL */
-    ppath = data->change.url;
-  }
-  if(HTTPREQ_POST_FORM == data->set.httpreq) {
-    /* we must build the whole darned post sequence first, so that we have
-       a size of the whole shebang before we start to send it */
-     result = Curl_getFormData(&http->sendit, data->set.httppost,
-                               &http->postsize);
-     if(CURLE_OK != result) {
-       /* Curl_getFormData() doesn't use failf() */
-       failf(data, "failed creating formpost data");
-       return result;
-     }
-  }
+  ptr = checkheaders(data, "Host:");
+  if(ptr) {
+    /* If we have a given custom Host: header, we extract the host name
+       in order to possibly use it for cookie reasons later on. */
+    char *start = ptr+strlen("Host:");
+    char *ptr;
+    while(*start && isspace((int)*start ))
+      start++;
+    ptr = start; /* start host-scanning here */
 
-  if(!checkheaders(data, "Host:")) {
+    /* scan through the string to find the end (space or colon) */
+    while(*ptr && !isspace((int)*ptr) && !(':'==*ptr))
+      ptr++;
+    
+    if(ptr != start) {
+      int len=ptr-start;
+      conn->allocptr.cookiehost = malloc(len+1);
+      if(!conn->allocptr.cookiehost)
+        return CURLE_OUT_OF_MEMORY;
+      memcpy(conn->allocptr.cookiehost, start, len);
+      conn->allocptr.cookiehost[len]=0;
+    }
+  }    
+  else {
     /* if ptr_host is already set, it is almost OK since we only re-use
        connections to the very same host and port, but when we use a HTTP
        proxy we have a persistant connect and yet we must change the Host:
@@ -765,6 +766,32 @@ CURLcode Curl_http(struct connectdata *conn)
                                     conn->remote_port);
   }
 
+  if(data->cookies) {
+    co = Curl_cookie_getlist(data->cookies,
+                             conn->allocptr.cookiehost?
+                             conn->allocptr.cookiehost:host, ppath,
+                             (bool)(conn->protocol&PROT_HTTPS?TRUE:FALSE));
+  }
+
+  if (data->change.proxy && *data->change.proxy &&
+      !data->set.tunnel_thru_httpproxy &&
+      !(conn->protocol&PROT_HTTPS))  {
+    /* The path sent to the proxy is in fact the entire URL */
+    ppath = data->change.url;
+  }
+  if(HTTPREQ_POST_FORM == data->set.httpreq) {
+    /* we must build the whole darned post sequence first, so that we have
+       a size of the whole shebang before we start to send it */
+     result = Curl_getFormData(&http->sendit, data->set.httppost,
+                               &http->postsize);
+     if(CURLE_OK != result) {
+       /* Curl_getFormData() doesn't use failf() */
+       failf(data, "failed creating formpost data");
+       return result;
+     }
+  }
+
+
   if(!checkheaders(data, "Pragma:"))
     http->p_pragma = "Pragma: no-cache\r\n";
 
