@@ -20,7 +20,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: urldata.h,v 1.149 2003/03/31 05:13:26 bagder Exp $
+ * $Id: urldata.h,v 1.152 2003/05/09 07:39:29 bagder Exp $
  ***************************************************************************/
 
 /* This file is for lib internal stuff */
@@ -93,6 +93,9 @@
    of need. */
 #define HEADERSIZE 256
 
+/* Maximum number of dirs supported by libcurl in a FTP dir hierarchy */
+#define CURL_MAX_FTP_DIRDEPTH 100
+
 /* Just a convenience macro to get the larger value out of two given */
 #ifndef MAX
 #define MAX(x,y) ((x)>(y)?(x):(y))
@@ -193,7 +196,7 @@ struct FTP {
   char *user;    /* user name string */
   char *passwd;  /* password string */
   char *urlpath; /* the originally given path part of the URL */
-  char *dir;     /* decoded directory */
+  char *dirs[CURL_MAX_FTP_DIRDEPTH]; /* path components */
   char *file;    /* decoded file */
 
   char *entrypath; /* the PWD reply when we logged on */
@@ -296,7 +299,7 @@ struct Curl_transfer_keeper {
 
 #ifdef HAVE_LIBZ
   bool zlib_init;		/* True if zlib already initialized;
-				   undefined if Content-Encdoing header. */
+				   undefined if Content-Encoding header. */
   z_stream z;			/* State structure for zlib. */
 #endif
 
@@ -435,6 +438,7 @@ struct connectdata {
     char *ref; /* free later if not NULL! */
     char *cookie; /* free later if not NULL! */
     char *host; /* free later if not NULL */
+    char *cookiehost; /* free later if not NULL */
   } allocptr;
 
   char *newurl; /* This can only be set if a Location: was in the
@@ -755,6 +759,7 @@ struct UserDefined {
   bool reuse_fresh;      /* do not re-use an existing connection  */
   bool expect100header;  /* TRUE if we added Expect: 100-continue */
   bool ftp_use_epsv;     /* if EPSV is to be attempted or not */
+  bool ftp_use_eprt;     /* if EPRT is to be attempted or not */
   bool no_signal;        /* do not use any signal/alarm handler */
 
   bool global_dns_cache;
