@@ -18,7 +18,7 @@
  * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
  * KIND, either express or implied.
  *
- * $Id: main.c,v 1.168 2003/03/31 04:42:20 bagder Exp $
+ * $Id: main.c,v 1.173 2003/05/12 12:45:57 bagder Exp $
  ***************************************************************************/
 
 /* This is now designed to have its own local setup.h */
@@ -345,7 +345,8 @@ static void help(void)
        " -C/--continue-at <offset> Specify absolute resume offset\n"
        " -d/--data <data>   HTTP POST data (H)\n"
        "    --data-ascii <data>   HTTP POST ASCII data (H)\n"
-       "    --data-binary <data>  HTTP POST binary data (H)\n"
+       "    --data-binary <data>  HTTP POST binary data (H)");
+  puts("    --disable-eprt  Prevents curl from using EPRT or LPRT (F)\n"
        "    --disable-epsv  Prevents curl from using EPSV (F)\n"
        " -D/--dump-header <file> Write the headers to this file\n"
        "    --egd-file <file> EGD socket path for random data (SSL)\n"
@@ -359,11 +360,11 @@ static void help(void)
        "    --key-type <type> Specifies private key  file type (DER/PEM/ENG) (HTTPS)\n"
        "    --pass  <pass>  Specifies passphrase for the private key (HTTPS)");
   puts("    --engine <eng>  Specifies the crypto engine to use (HTTPS)\n"
-       "    --cacert <file> CA certifciate to verify peer against (SSL)\n"
+       "    --cacert <file> CA certificate to verify peer against (SSL)\n"
        "    --capath <directory> CA directory (made using c_rehash) to verify\n"
        "                    peer against (SSL)\n"
        "    --ciphers <list> What SSL ciphers to use (SSL)\n"
-       "    --compressed    Request a compressed response (using deflate).");
+       "    --compressed    Request a compressed response (using deflate or gzip).");
   puts("    --connect-timeout <seconds> Maximum time allowed for connection\n"
        "    --create-dirs   Create the necessary local directory hierarchy\n"
        "    --crlf          Convert LF to CRLF in upload. Useful for MVS (OS/390)\n"
@@ -445,6 +446,7 @@ struct Configurable {
   bool use_resume;
   bool resume_from_current;
   bool disable_epsv;
+  bool disable_eprt;
   int resume_from;
   char *postfields;
   long postfieldsize;
@@ -1213,6 +1215,9 @@ static ParameterError getparameter(char *flag, /* f or -long-flag */
       case 'e': /* --disable-epsv */
         config->disable_epsv ^= TRUE;
         break;
+      case 'f': /* --disable-eprt */
+        config->disable_eprt ^= TRUE;
+        break;
 #ifdef USE_ENVIRONMENT
       case 'f':
         config->writeenv ^= TRUE;
@@ -2932,6 +2937,11 @@ operate(struct Configurable *config, int argc, char *argv[])
         /* disable it */
         curl_easy_setopt(curl, CURLOPT_FTP_USE_EPSV, FALSE);
 
+      /* new in libcurl 7.10.5 */
+      if(config->disable_eprt)
+        /* disable it */
+        curl_easy_setopt(curl, CURLOPT_FTP_USE_EPRT, FALSE);
+      
       /* new in curl 7.9.7 */
       if(config->trace_dump) {
         curl_easy_setopt(curl, CURLOPT_DEBUGFUNCTION, my_trace);
@@ -2942,7 +2952,7 @@ operate(struct Configurable *config, int argc, char *argv[])
 
       /* new in curl 7.10 */
       curl_easy_setopt(curl, CURLOPT_ENCODING, 
-                       (config->encoding) ? "deflate" : NULL);
+                       (config->encoding) ? "" : NULL);
 
       res = curl_easy_perform(curl);
         
@@ -2966,8 +2976,31 @@ operate(struct Configurable *config, int argc, char *argv[])
         vms_show = VMSSTS_HIDE;
       }
 #else
-      if((res!=CURLE_OK) && config->showerror)
-        fprintf(config->errors, "curl: (%d) %s\n", res, errorbuffer);
+      if((res!=CURLE_OK) && config->showerror) {
+        if(CURLE_SSL_CACERT == res) {
+          fprintf(config->errors, "curl: (%d) %s\n\n", res, errorbuffer);
+#define CURL_CA_CERT_ERRORMSG1 \
+"More details here: http://curl.haxx.se/docs/sslcerts.html\n\n" \
+"curl performs SSL certificate verification by default, using a \"bundle\"\n" \
+" of Certificate Authority (CA) public keys (CA certs). The default\n" \
+" bundle is named curl-ca-bundle.crt; you can specify an alternate file\n" \
+" using the --cacert option.\n"
+
+#define CURL_CA_CERT_ERRORMSG2 \
+"If this HTTPS server uses a certificate signed by a CA represented in\n" \
+" the bundle, the certificate verification probably failed due to a\n" \
+" problem with the certificate (it might be expired, or the name might\n" \
+" not match the domain name in the URL).\n" \
+"If you'd like to turn off curl's verification of the certificate, use\n" \
+" the -k (or --insecure) option.\n"
+
+          fprintf(config->errors, "%s%s",
+                  CURL_CA_CERT_ERRORMSG1,
+                  CURL_CA_CERT_ERRORMSG2 );
+        }
+        else
+          fprintf(config->errors, "curl: (%d) %s\n", res, errorbuffer);
+      }
 #endif
 
       if (outfile && !curl_strequal(outfile, "-") && outs.stream)
